USE AdventureWorks2008R2
GO

SELECT DocumentNode, DocumentSummary, Document
FROM Production.Document AS DocTable INNER JOIN
CONTAINSTABLE(Production.Document, Document, 
              'NEAR(reflector,bracket)' ) AS KEY_TBL
ON DocTable.DocumentNode = KEY_TBL.[KEY];
GO

-- reflector within 2 words of bracket
SELECT DocumentNode, DocumentSummary, Document
FROM Production.Document AS DocTable INNER JOIN
CONTAINSTABLE(Production.Document, Document, 
			  'NEAR((reflector,bracket),2)' ) AS KEY_TBL
ON DocTable.DocumentNode = KEY_TBL.[KEY];
GO

-- reflector within 2 words of bracket and in order
SELECT DocumentNode, DocumentSummary, Document
FROM Production.Document AS DocTable INNER JOIN
CONTAINSTABLE(Production.Document, Document, 
              'NEAR((reflector,bracket),2, TRUE)' ) AS KEY_TBL
ON DocTable.DocumentNode = KEY_TBL.[KEY];
GO

-- bracket within 2 words of reflector and in order
SELECT DocumentNode, DocumentSummary, Document
FROM Production.Document AS DocTable INNER JOIN
CONTAINSTABLE(Production.Document, Document, 
              'NEAR((bracket,reflector),2, TRUE)' ) AS KEY_TBL
ON DocTable.DocumentNode = KEY_TBL.[KEY];
GO

-- Generic search terms, order doesn't matter
SELECT DocumentNode, DocumentSummary, Document
FROM Production.Document AS DocTable INNER JOIN
CONTAINSTABLE(Production.Document, Document, 
              '(Reflector NEAR Bracket)' ) AS KEY_TBL
ON DocTable.DocumentNode = KEY_TBL.[KEY]
ORDER BY KEY_TBL.RANK;
GO

SELECT DocumentNode, DocumentSummary, Document
FROM Production.Document AS DocTable INNER JOIN
CONTAINSTABLE(Production.Document, Document, 
              '(Bracket NEAR Reflector)' ) AS KEY_TBL
ON DocTable.DocumentNode = KEY_TBL.[KEY]
ORDER BY KEY_TBL.RANK;
GO

-- You can use the tilde character (~) in place of the NEAR 
-- keyword in the earlier query, and get the same results:
SELECT DocumentNode, DocumentSummary, Document
FROM Production.Document AS DocTable INNER JOIN
CONTAINSTABLE(Production.Document, Document, 
              '(Reflector ~ Bracket)' ) AS KEY_TBL
ON DocTable.DocumentNode = KEY_TBL.[KEY]
ORDER BY KEY_TBL.RANK;
